@@ -1,30 +1,30 @@
 # @file Evaluation.R
 #
-# Copyright 2021 Observational Health Data Sciences and Informatics
+# Copyright 2022 Observational Health Data Sciences and Informatics
 #
 # This file is part of EmpiricalCalibration
-# 
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #     http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-#' Evaluate confidence interval calibration 
+#' Evaluate confidence interval calibration
 #'
 #' @description
-#' \code{evaluateCiCalibration} performs a leave-one-out cross-validation to evaluate the calibration 
+#' \code{evaluateCiCalibration} performs a leave-one-out cross-validation to evaluate the calibration
 #' confidence intervals.
 #'
 #' @details
 #' The empirical calibration is performed using a leave-one-out design: The confidence interval of an
-#' effect is computed by fitting a null using all other controls. 
+#' effect is computed by fitting a null using all other controls.
 #'
 #' @param logRr                  A numeric vector of effect estimates on the log scale.
 #' @param seLogRr                The standard error of the log of the effect estimates. Hint: often the
@@ -37,7 +37,7 @@
 #'                               is a single control, but a different grouping can be provided, for
 #'                               example linking a negative control to synthetic positive controls
 #'                               derived from that negative control.
-#' @param legacy                 If true, a legacy error model will be fitted, meaning standard 
+#' @param legacy                 If true, a legacy error model will be fitted, meaning standard
 #'                               deviation is linear on the log scale. If false, standard deviation
 #'                               is assumed to be simply linear.
 #'
@@ -58,15 +58,19 @@ evaluateCiCalibration <- function(logRr,
                                   strata = as.factor(trueLogRr),
                                   crossValidationGroup = 1:length(logRr),
                                   legacy = FALSE) {
-  if (!is.null(strata) && !is.factor(strata))
+  if (!is.null(strata) && !is.factor(strata)) {
     stop("Strata argument should be a factor (or null)")
-  if (is.null(strata))
-    strata = as.factor(-1)
-  data <- data.frame(logRr = logRr,
-                     seLogRr = seLogRr,
-                     trueLogRr = trueLogRr,
-                     strata = strata,
-                     crossValidationGroup = crossValidationGroup)
+  }
+  if (is.null(strata)) {
+    strata <- as.factor(-1)
+  }
+  data <- data.frame(
+    logRr = logRr,
+    seLogRr = seLogRr,
+    trueLogRr = trueLogRr,
+    strata = strata,
+    crossValidationGroup = crossValidationGroup
+  )
   if (any(is.infinite(data$seLogRr))) {
     warning("Estimate(s) with infinite standard error detected. Removing before fitting error model")
     data <- data[!is.infinite(seLogRr), ]
@@ -84,15 +88,18 @@ evaluateCiCalibration <- function(logRr,
     data <- data[!is.na(logRr), ]
   }
   computeCoverage <- function(j, subResult, dataLeftOut, model) {
-    subset <- dataLeftOut[dataLeftOut$strata == subResult$strata[j],]
-    if (nrow(subset) == 0)
+    subset <- dataLeftOut[dataLeftOut$strata == subResult$strata[j], ]
+    if (nrow(subset) == 0) {
       return(0)
+    }
     # writeLines(paste0("ciWidth: ", subResult$ciWidth[j], ", strata: ", subResult$strata[j], ", model: ", paste(model, collapse = ",")))
     # writeLines(paste0("ciWidth: ", subResult$ciWidth[j], ", logRr: ", paste(subset$logRr, collapse = ","), ", seLogRr:", paste(subset$seLogRr, collapse = ","), ", model: ", paste(model, collapse = ",")))
-    ci <- EmpiricalCalibration::calibrateConfidenceInterval(logRr = subset$logRr,
-                                                            seLogRr = subset$seLogRr,
-                                                            ciWidth = subResult$ciWidth[j],
-                                                            model = model)
+    ci <- EmpiricalCalibration::calibrateConfidenceInterval(
+      logRr = subset$logRr,
+      seLogRr = subset$seLogRr,
+      ciWidth = subResult$ciWidth[j],
+      model = model
+    )
     ci$logLb95Rr[is.na(ci$logLb95Rr)] <- 0
     ci$logUb95Rr[is.na(ci$logUb95Rr)] <- 999
     below <- sum(subset$trueLogRr < ci$logLb95Rr)
@@ -101,37 +108,40 @@ evaluateCiCalibration <- function(logRr,
 
     return(c(below, within, above))
   }
-  
+
   computeTheoreticalCoverage <- function(j, subResult, dataLeftOut) {
-    subset <- dataLeftOut[dataLeftOut$strata == subResult$strata[j],]
+    subset <- dataLeftOut[dataLeftOut$strata == subResult$strata[j], ]
     ciWidth <- subResult$ciWidth[j]
-    logLb95Rr <- subset$logRr + qnorm((1 - ciWidth)/2)*subset$seLogRr
-    logUb95Rr <- subset$logRr - qnorm((1 - ciWidth)/2)*subset$seLogRr
+    logLb95Rr <- subset$logRr + qnorm((1 - ciWidth) / 2) * subset$seLogRr
+    logUb95Rr <- subset$logRr - qnorm((1 - ciWidth) / 2) * subset$seLogRr
     below <- sum(subset$trueLogRr < logLb95Rr)
     within <- sum(subset$trueLogRr >= logLb95Rr & subset$trueLogRr <= logUb95Rr)
     above <- sum(subset$trueLogRr > logUb95Rr)
     return(c(below, within, above))
   }
-  
+
   computeLooCoverage <- function(leaveOutGroup, data, legacy) {
     dataLeaveOneOut <- data[data$crossValidationGroup != leaveOutGroup, ]
     dataLeftOut <- data[data$crossValidationGroup == leaveOutGroup, ]
-    if (nrow(dataLeaveOneOut) == 0 || nrow(dataLeftOut) == 0)
+    if (nrow(dataLeaveOneOut) == 0 || nrow(dataLeftOut) == 0) {
       return(data.frame())
-    
-    model <- fitSystematicErrorModel(logRr = dataLeaveOneOut$logRr,
-                                     seLogRr = dataLeaveOneOut$seLogRr,
-                                     trueLogRr = dataLeaveOneOut$trueLogRr,
-                                     estimateCovarianceMatrix = FALSE,
-                                     legacy = legacy)
+    }
+
+    model <- fitSystematicErrorModel(
+      logRr = dataLeaveOneOut$logRr,
+      seLogRr = dataLeaveOneOut$seLogRr,
+      trueLogRr = dataLeaveOneOut$trueLogRr,
+      estimateCovarianceMatrix = FALSE,
+      legacy = legacy
+    )
     strata <- unique(dataLeftOut$strata)
     ciWidth <- seq(0.01, 0.99, by = 0.01)
     subResult <- expand.grid(strata, ciWidth)
     names(subResult) <- c("strata", "ciWidth")
     coverage <- sapply(1:nrow(subResult), computeCoverage, subResult = subResult, dataLeftOut = dataLeftOut, model = model)
-    subResult$below <- coverage[1,]
-    subResult$within <- coverage[2,]
-    subResult$above <- coverage[3,]
+    subResult$below <- coverage[1, ]
+    subResult$within <- coverage[2, ]
+    subResult$above <- coverage[3, ]
     theoreticalCoverage <- sapply(1:nrow(subResult), computeTheoreticalCoverage, subResult = subResult, dataLeftOut = dataLeftOut)
     subResult$theoreticalBelow <- theoreticalCoverage[1, ]
     subResult$theoreticalWithin <- theoreticalCoverage[2, ]
@@ -173,12 +183,14 @@ evaluateCiCalibration <- function(logRr,
   aboveUncali$coverage <- aboveUncali$theoreticalAbove / aboveUncali$count
   aboveUncali$label <- "Above confidence interval"
   aboveUncali$type <- "Uncalibrated"
-  vizData <- rbind(belowCali[, c("strata", "label", "type", "ciWidth", "coverage")],
-                   withinCali[, c("strata", "label", "type", "ciWidth", "coverage")],
-                   aboveCali[, c("strata", "label", "type", "ciWidth", "coverage")],
-                   belowUncali[, c("strata", "label", "type", "ciWidth", "coverage")],
-                   withinUncali[, c("strata", "label", "type", "ciWidth", "coverage")],
-                   aboveUncali[, c("strata", "label", "type", "ciWidth", "coverage")])
+  vizData <- rbind(
+    belowCali[, c("strata", "label", "type", "ciWidth", "coverage")],
+    withinCali[, c("strata", "label", "type", "ciWidth", "coverage")],
+    aboveCali[, c("strata", "label", "type", "ciWidth", "coverage")],
+    belowUncali[, c("strata", "label", "type", "ciWidth", "coverage")],
+    withinUncali[, c("strata", "label", "type", "ciWidth", "coverage")],
+    aboveUncali[, c("strata", "label", "type", "ciWidth", "coverage")]
+  )
   names(vizData)[names(vizData) == "type"] <- "Confidence interval calculation"
   vizData$trueRr <- as.factor(exp(as.numeric(as.character(vizData$strata))))
   vizData$strata <- NULL
