@@ -1,15 +1,15 @@
 # @file Likelihoods.R
 #
-# Copyright 2021 Observational Health Data Sciences and Informatics
+# Copyright 2022 Observational Health Data Sciences and Informatics
 #
 # This file is part of EmpiricalCalibration
-# 
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #     http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -17,7 +17,7 @@
 # limitations under the License.
 
 gaussianProduct <- function(mu1, mu2, sd1, sd2) {
-  (2 * pi)^(-1/2) * (sd1^2 + sd2^2)^(-1/2) * exp(-(mu1 - mu2)^2/(2 * (sd1^2 + sd2^2)))
+  (2 * pi)^(-1 / 2) * (sd1^2 + sd2^2)^(-1 / 2) * exp(-(mu1 - mu2)^2 / (2 * (sd1^2 + sd2^2)))
 }
 
 # logLikelihoodNullOld <- function(theta, logRr, seLogRr) {
@@ -30,7 +30,7 @@ gaussianProduct <- function(mu1, mu2, sd1, sd2) {
 #     for (i in 1:length(logRr)) {
 #       result <- result - dnorm(theta[1], logRr[i], seLogRr[i], log = TRUE)
 #     }
-#     
+#
 #   } else {
 #     # Note: not faster when vectorized
 #     for (i in 1:length(logRr)) {
@@ -44,7 +44,7 @@ gaussianProduct <- function(mu1, mu2, sd1, sd2) {
 
 logLikelihoodNullMcmc <- function(theta, logRr, seLogRr) {
   result <- logLikelihoodNull(theta, logRr, seLogRr)
-  
+
   # Add weak prior for when precision becomes very large:
   result <- result - dgamma(theta[2], shape = 1e-04, rate = 1e-04, log = TRUE)
   return(result)
@@ -63,8 +63,9 @@ minLogLikelihoodErrorModel <- function(theta, logRr, seLogRr, trueLogRr) {
     }
   }
   result <- sum(sapply(1:length(logRr), estimateLl))
-  if (is.infinite(result) || is.na(result))
+  if (is.infinite(result) || is.na(result)) {
     result <- 99999
+  }
   result
 }
 
@@ -75,39 +76,44 @@ minLogLikelihoodErrorModelLegacy <- function(theta, logRr, seLogRr, trueLogRr) {
     sd <- exp(theta[3] + theta[4] * trueLogRr[i])
     result <- result - log(gaussianProduct(logRr[i], mean, seLogRr[i], sd))
   }
-  if (is.infinite(result) || is.na(result))
+  if (is.infinite(result) || is.na(result)) {
     result <- 99999
+  }
   result
 }
 
 profileProduct <- function(x, mu, sigma, llApproximationFunction, likelihoodApproximation) {
-  return(exp(dnorm(x, mu, sigma, log = TRUE) + 
-               llApproximationFunction(x = x, parameters = likelihoodApproximation)))
+  return(exp(dnorm(x, mu, sigma, log = TRUE) +
+    llApproximationFunction(x = x, parameters = likelihoodApproximation)))
 }
 
 logLikelihoodNullNonNormalLl <- function(theta, llApproximationFunction, likelihoodApproximations) {
-  if (theta[2] <= 0)
+  if (theta[2] <= 0) {
     return(99999)
+  }
   result <- 0
-  sd <- 1/sqrt(theta[2])
+  sd <- 1 / sqrt(theta[2])
   if (sd < 1e-6) {
     for (i in 1:length(likelihoodApproximations)) {
       result <- result - llApproximationFunction(x = theta[1], parameters = likelihoodApproximations[[i]])
     }
   } else {
     for (i in 1:length(likelihoodApproximations)) {
-      result <- result - log(integrate(f = profileProduct,
-                                       lower = theta[1] - 10 * sd,
-                                       upper = theta[1] + 10 * sd, 
-                                       mu = theta[1],
-                                       sigma = sd,
-                                       llApproximationFunction = llApproximationFunction,
-                                       likelihoodApproximation = likelihoodApproximations[[i]],
-                                       stop.on.error = FALSE)$value)
+      result <- result - log(integrate(
+        f = profileProduct,
+        lower = theta[1] - 10 * sd,
+        upper = theta[1] + 10 * sd,
+        mu = theta[1],
+        sigma = sd,
+        llApproximationFunction = llApproximationFunction,
+        likelihoodApproximation = likelihoodApproximations[[i]],
+        stop.on.error = FALSE
+      )$value)
     }
   }
-  if (length(result) == 0 || is.infinite(result))
+  if (length(result) == 0 || is.infinite(result)) {
     result <- 99999
+  }
   result
 }
 
@@ -116,15 +122,15 @@ normalLlApproximaton <- function(x, parameters) {
 }
 
 customLlApproximation <- function(x, parameters) {
-  return(((exp(parameters$gamma * (x - parameters$mu)))) * 
-           ((-(x - parameters$mu)^2)/(2 * parameters$sigma^2)))
+  return(((exp(parameters$gamma * (x - parameters$mu)))) *
+    ((-(x - parameters$mu)^2) / (2 * parameters$sigma^2)))
 }
 
 skewNormalLlApproximation <- function(x, parameters) {
   if (is.infinite(parameters$sigma)) {
     return(rep(0, length(x)))
   }
-  return(log(2) + 
-           dnorm(x, parameters$mu, parameters$sigma, log = TRUE) + 
-           pnorm(parameters$alpha * (x - parameters$mu), 0, parameters$sigma, log.p = TRUE))
+  return(log(2) +
+    dnorm(x, parameters$mu, parameters$sigma, log = TRUE) +
+    pnorm(parameters$alpha * (x - parameters$mu), 0, parameters$sigma, log.p = TRUE))
 }
